<?php
/**
 * LSVR Document List Widget Shortcode
 */
if ( ! class_exists( 'Lsvr_Shortcode_Document_Attachments_Widget' ) ) {
    class Lsvr_Shortcode_Document_Attachments_Widget {

        public static function shortcode( $atts = array(), $content = null, $tag ) {

            // Merge default atts and received atts
            $args = shortcode_atts(
                array(
                    'title' => '',
                    'icon' => '',
                    'category' => 0,
                    'tags' => '',
                    'limit' => 4,
                    'show_attachment_titles' => 'false',
                    'more_label' => '',
                    'id' => '',
                ),
                $atts
            );

            ob_start(); ?>

            <?php the_widget( 'Lsvr_Widget_Document_Attachments', array(
                'title' => $args['title'],
                'category' => $args['category'],
                'tags' => $args['tags'],
                'limit' => $args['limit'],
                'show_attachment_titles' => $args['show_attachment_titles'],
                'more_label' => $args['more_label'],
            ), array(
                'before_widget' => '<div' . ( ! empty( $args['id'] ) ? ' id="' . esc_attr( $args['id'] ) . '"' : '' ) . ' class="widget lsvr_document-attachments-widget"><div class="widget__inner">',
                'after_widget' => '</div></div>',
                'before_title' => ! empty( $args['icon'] ) ? '<h3 class="widget__title widget__title--has-icon"><i class="widget__title-icon ' . esc_attr( $args['icon'] ) . '"></i>' : '<h3 class="widget__title">',
                'after_title' => '</h3>',
            )); ?>

            <?php return ob_get_clean();

        }

        // Shortcode params
        public static function lsvr_shortcode_params() {
            return array(
                'base' => 'lsvr_document_attachments_widget',
                'title' => __( 'LSVR Document Attachments Widget', 'lsvr-documents' ),
                'description' => __( 'List of document attachments', 'lsvr-documents' ),
                'category' => esc_html__( 'LSVR Widgets', 'lsvr-documents' ),
                'is_widget' => true,
                'fields' => array(

                    // Title
                    'title' => array(
                        'type' => 'text',
                        'label' => esc_html__( 'Title', 'lsvr-documents' ),
                        'description' => esc_html__( 'Title of this section.', 'lsvr-documents' ),
                    ),

                    // Category
                    'category' => array(
                        'type' => 'taxonomy',
                        'tax' => 'lsvr_document_cat',
                        'label' => esc_html__( 'Category', 'lsvr-documents' ),
                        'description' => esc_html__( 'Display attachments from a specific category.', 'lsvr-documents' ),
                    ),

                    // Tags
                    'tags' => array(
                        'type' => 'text',
                        'label' => esc_html__( 'Tags', 'lsvr-documents' ),
                        'description' => esc_html__( 'Display only attachments which contain certain tags. Separate tag slugs by comma.', 'lsvr-documents' ),
                    ),

                    // Limit
                    'limit' => array(
                        'type' => 'select',
                        'label' => esc_html__( 'Limit', 'lsvr-documents' ),
                        'description' => esc_html__( 'How many attachments to display.', 'lsvr-documents' ),
                        'choices' => array( 0 => esc_html__( 'All', 'lsvr-documents' ) ) + range( 1, 20, 1 ),
                        'default' => 4,
                    ),

                    // Display attachment titles
                    'show_attachment_titles' => array(
                        'type' => 'checkbox',
                        'label' => esc_html__( 'Display Attachment Titles', 'lsvr-documents' ),
                        'description' => esc_html__( 'Display titles instead of file names. You can edit titles under Media.', 'lsvr-documents' ),
                        'default' => false,
                    ),

                    // More label
                    'more_label' => array(
                        'type' => 'text',
                        'label' => esc_html__( 'More Link Label', 'lsvr-documents' ),
                        'description' => esc_html__( 'Link to documents archive. Leave blank to hide.', 'lsvr-documents' ),
                    ),

                    // ID
                    'id' => array(
                        'type' => 'text',
                        'label' => esc_html__( 'Unique ID', 'lsvr-documents' ),
                        'description' => esc_html__( 'You can use this ID to style this specific element with custom CSS, for example.', 'lsvr-documents' ),
                    ),

                )
            );
        }

    }
}
?>