<?php
/**
 * LSVR Featured Document Widget Shortcode
 */
if ( ! class_exists( 'Lsvr_Shortcode_Document_Featured_Widget' ) ) {
    class Lsvr_Shortcode_Document_Featured_Widget {

        public static function shortcode( $atts = array(), $content = null, $tag ) {

            // Merge default atts and received atts
            $args = shortcode_atts(
                array(
                    'title' => '',
                    'icon' => '',
                    'post' => '',
                    'show_date' => 'true',
                    'show_category' => 'true',
                    'show_excerpt' => 'true',
                    'show_attachments' => 'true',
                    'show_attachment_titles' => 'false',
                    'more_label' => '',
                    'id' => '',
                ),
                $atts
            );

            ob_start(); ?>

            <?php the_widget( 'Lsvr_Widget_Document_Featured', array(
                'title' => $args['title'],
                'post' => $args['post'],
                'show_date' => $args['show_date'],
                'show_category' => $args['show_category'],
                'show_excerpt' => $args['show_excerpt'],
                'show_attachments' => $args['show_attachments'],
                'show_attachment_titles' => $args['show_attachment_titles'],
                'more_label' => $args['more_label'],
            ), array(
                'before_widget' => '<div' . ( ! empty( $args['id'] ) ? ' id="' . esc_attr( $args['id'] ) . '"' : '' ) . ' class="widget lsvr_document-featured-widget"><div class="widget__inner">',
                'after_widget' => '</div></div>',
                'before_title' => ! empty( $args['icon'] ) ? '<h3 class="widget__title widget__title--has-icon"><i class="widget__title-icon ' . esc_attr( $args['icon'] ) . '"></i>' : '<h3 class="widget__title">',
                'after_title' => '</h3>',
            )); ?>

            <?php return ob_get_clean();

        }

        // Shortcode params
        public static function lsvr_shortcode_params() {
            return array(
                'base' => 'lsvr_document_featured_widget',
                'title' => __( 'LSVR Featured Document Widget', 'lsvr-documents' ),
                'description' => __( 'Single document post', 'lsvr-documents' ),
                'category' => esc_html__( 'LSVR Widgets', 'lsvr-documents' ),
                'is_widget' => true,
                'fields' => array(

                    // Title
                    'title' => array(
                        'type' => 'text',
                        'label' => esc_html__( 'Title', 'lsvr-documents' ),
                        'description' => esc_html__( 'Title of this section.', 'lsvr-documents' ),
                    ),

                    // Post
                    'post' => array(
                        'type' => 'post',
                        'post_type' => 'lsvr_document',
                        'label' => esc_html__( 'Category', 'lsvr-documents' ),
                        'description' => esc_html__( 'Choose document to display.', 'lsvr-documents' ),
                    ),

                    // Display date
                    'show_date' => array(
                        'type' => 'checkbox',
                        'label' => esc_html__( 'Display Date', 'lsvr-documents' ),
                        'default' => true,
                    ),

                    // Display category
                    'show_category' => array(
                        'type' => 'checkbox',
                        'label' => esc_html__( 'Display Category', 'lsvr-documents' ),
                        'default' => true,
                    ),

                    // Display excerpt
                    'show_excerpt' => array(
                        'type' => 'checkbox',
                        'label' => esc_html__( 'Display Excerpt', 'lsvr-documents' ),
                        'default' => true,
                    ),

                    // Display attachments
                    'show_attachments' => array(
                        'type' => 'checkbox',
                        'label' => esc_html__( 'Display Attachments', 'lsvr-documents' ),
                        'default' => true,
                    ),

                    // Display attachment titles
                    'show_attachment_titles' => array(
                        'type' => 'checkbox',
                        'label' => esc_html__( 'Display Attachment Titles', 'lsvr-documents' ),
                        'description' => esc_html__( 'Display titles instead of file names. You can edit titles under Media.', 'lsvr-documents' ),
                        'default' => false,
                    ),

                    // More label
                    'more_label' => array(
                        'type' => 'text',
                        'label' => esc_html__( 'More Link Label', 'lsvr-documents' ),
                        'description' => esc_html__( 'Link to documents archive. Leave blank to hide.', 'lsvr-documents' ),
                    ),

                    // ID
                    'id' => array(
                        'type' => 'text',
                        'label' => esc_html__( 'Unique ID', 'lsvr-documents' ),
                        'description' => esc_html__( 'You can use this ID to style this specific element with custom CSS, for example.', 'lsvr-documents' ),
                    ),

                )
            );
        }

    }
}
?>