<?php

// Get posts
if ( ! function_exists( 'lsvr_get_posts' ) ) {
    function lsvr_get_posts( $post_type = 'post' ) {

        $posts_parsed = array();

        if ( post_type_exists( $post_type ) ) {

            // Get posts
            $posts = get_posts(array(
                'post_type' => $post_type,
                'posts_per_page' => 1000,
                'orderby' => 'title',
                'order' => 'ASC',
            ));

            // Parse posts
            if ( ! empty( $posts ) ) {
                foreach ( $posts as $post ) {
                    $posts_parsed[ $post->ID ] = $post->post_title;
                }
            }

        }

        return ! empty( $posts_parsed ) ? $posts_parsed : array();

    }
}

// Get taxonomy terms
if ( ! function_exists( 'lsvr_get_terms' ) ) {
	function lsvr_get_terms( $taxonomy ) {

		$terms_parsed = array();

        if ( taxonomy_exists( $taxonomy ) ) {

        	// Get terms
            $tax_terms = get_terms(array(
                'taxonomy' => $taxonomy,
                'orderby' => 'name',
                'hide_empty' => true,
            ));

            // Parse terms
            if ( ! empty( $tax_terms ) ) {
            	foreach ( $tax_terms as $term ) {
            		$terms_parsed[ $term->term_id ] = $term->name;
            	}
            }

        }

        return ! empty( $terms_parsed ) ? $terms_parsed : array();

    }
}

// Get menus
if ( ! function_exists( 'lsvr_get_menus' ) ) {
	function lsvr_get_menus() {

		$return = array();

		$menus = wp_get_nav_menus();
		if ( ! empty( $menus ) ) {
			foreach ( $menus as $menu ) {
				if ( ! empty( $menu->term_id ) && ! empty( $menu->name ) ) {
					$return[ $menu->term_id ] = $menu->name;
				}
			}
		}

		return $return;

	}
}

// Convert element field type to VC field type
function lsvr_element_field_type_to_vc_field_type( $param ) {

	$map = array(
		'text' => 'textfield',
		'select' => 'dropdown',
		'image' => 'attach_image',
	);

	return ! empty( $map[ $param ] ) ? $map[ $param ] : $param;

}

// Convert shortcode to page builder element
function lsvr_shortcode_to_element( $shortcode_params = array() ) {

	if ( ! empty( $shortcode_params['fields'] ) && ( function_exists( 'vc_map' ) ) ) {

		// Add icon field
		if ( ! empty( $shortcode_params['is_widget'] ) && true === $shortcode_params['is_widget'] &&
			true === apply_filters( 'lsvr_shortcode_to_element_add_icon_field', false ) ) {

			$shortcode_params['fields']['icon'] = array(
                'type' => 'text',
                'label' => esc_html__( 'Icon', 'lsvr-framework' ),
                'description' => esc_html__( 'Insert icon class name. Please refer to the documentation to learn more about icons.', 'lsvr-townpress-framework' ),
			);

		}

		// Convert tax and post fields to selectboxes with real values
		foreach ( $shortcode_params['fields'] as $field_id => $field_params ) {

			// Post
			if ( 'post' === $field_params['type'] && ! empty( $field_params['post_type'] ) ) {
				$shortcode_params['fields'][ $field_id ]['type'] = 'select';
				$shortcode_params['fields'][ $field_id ]['choices'] = lsvr_get_posts( $field_params['post_type'] );
			}

			// Tax
			if ( 'taxonomy' === $field_params['type'] && ! empty( $field_params['tax'] ) ) {
				$shortcode_params['fields'][ $field_id ]['type'] = 'select';
				$shortcode_params['fields'][ $field_id ]['choices'] = array( esc_html__( '---', 'lsvr-framework' ) => 0 ) + lsvr_get_terms( $field_params['tax'] );
			}

			// Menu
			if ( 'menu' === $field_params['type'] ) {
				$shortcode_params['fields'][ $field_id ]['type'] = 'select';
				$shortcode_params['fields'][ $field_id ]['choices'] = lsvr_get_menus();
			}

		}

		// Convert shortcode to VC element
		$vc_params = array();

		// If the element has content area, add the appropriate field
		if ( ! empty( $shortcode_params['has_content'] ) && true === $shortcode_params['has_content'] ) {
			array_push( $vc_params, array(
				'param_name' => 'content',
            	'type' => 'textarea_html',
            	'heading' => esc_html__( 'Text', 'lsvr-framework' ),
			));
		}

		// Convert fields to VC params
		if ( ! empty( $shortcode_params['fields'] ) ) {
			foreach ( $shortcode_params['fields'] as $field_id => $field_params ) {

				// ID
				$vc_field = array(
					'param_name' => $field_id,
				);

				// Type
				if ( ! empty( $field_params['type'] ) ) {
					$vc_field['type'] = lsvr_element_field_type_to_vc_field_type( $field_params['type'] );
				}

				// Label
				if ( ! empty( $field_params['label'] ) ) {
					$vc_field['heading'] = $field_params['label'];
				}

				// Description
				if ( ! empty( $field_params['description'] ) ) {
					$vc_field['description'] = $field_params['description'];
				}

				// Choices
				if ( ! empty( $field_params['choices'] ) ) {
					$vc_field['value'] = array_flip( (array) $field_params['choices'] );
				}

				// Default
				if ( ! empty( $field_params['default'] ) ) {
					$vc_field['std'] = $field_params['default'];
				}

				array_push( $vc_params, $vc_field );

			}
		}

		// VC map
	    vc_map( array(
	        'weight' => 2000,
	        'base' => ! empty( $shortcode_params['base'] ) ? $shortcode_params['base'] : '',
	        'name' => ! empty( $shortcode_params['title'] ) ? $shortcode_params['title'] : '',
	        'description' => ! empty( $shortcode_params['description'] ) ? $shortcode_params['description'] : '',
	        'category' => ! empty( $shortcode_params['category'] ) ? $shortcode_params['category'] : '',
	        'content_element' => true,
	        'show_settings_on_create' => true,
	        'params' => $vc_params,
        ));

	}

}

?>