<?php
/**
 * LSVR Gallery List Widget Shortcode
 */
if ( ! class_exists( 'Lsvr_Shortcode_Gallery_List_Widget' ) ) {
    class Lsvr_Shortcode_Gallery_List_Widget {

        public static function shortcode( $atts = array(), $content = null, $tag ) {

            // Merge default atts and received atts
            $args = shortcode_atts(
                array(
                    'title' => '',
                    'icon' => '',
                    'category' => 0,
                    'limit' => 4,
                    'show_date' => 'true',
                    'show_image_count' => 'true',
                    'more_label' => '',
                    'id' => '',
                ),
                $atts
            );

            ob_start(); ?>

            <?php the_widget( 'Lsvr_Widget_Gallery_List', array(
                'title' => $args['title'],
                'category' => $args['category'],
                'limit' => $args['limit'],
                'show_date' => $args['show_date'],
                'show_image_count' => $args['show_image_count'],
                'more_label' => $args['more_label'],
            ), array(
                'before_widget' => '<div' . ( ! empty( $args['id'] ) ? ' id="' . esc_attr( $args['id'] ) . '"' : '' ) . ' class="widget lsvr_gallery-list-widget"><div class="widget__inner">',
                'after_widget' => '</div></div>',
                'before_title' => ! empty( $args['icon'] ) ? '<h3 class="widget__title widget__title--has-icon"><i class="widget__title-icon ' . esc_attr( $args['icon'] ) . '"></i>' : '<h3 class="widget__title">',
                'after_title' => '</h3>',
            )); ?>

            <?php return ob_get_clean();

        }

        // Shortcode params
        public static function lsvr_shortcode_params() {
            return array(
                'base' => 'lsvr_gallery_list_widget',
                'title' => __( 'LSVR Galleries Widget', 'lsvr-galleries' ),
                'description' => __( 'List of gallery posts', 'lsvr-galleries' ),
                'category' => esc_html__( 'LSVR Widgets', 'lsvr-galleries' ),
                'is_widget' => true,
                'fields' => array(

                    // Title
                    'title' => array(
                        'type' => 'text',
                        'label' => esc_html__( 'Title', 'lsvr-galleries' ),
                        'description' => esc_html__( 'Title of this section.', 'lsvr-galleries' ),
                    ),

                    // Category
                    'category' => array(
                        'type' => 'taxonomy',
                        'tax' => 'lsvr_gallery_cat',
                        'label' => esc_html__( 'Category', 'lsvr-galleries' ),
                        'description' => esc_html__( 'Display galleries from a specific category.', 'lsvr-galleries' ),
                    ),

                    // Limit
                    'limit' => array(
                        'type' => 'select',
                        'label' => esc_html__( 'Limit', 'lsvr-galleries' ),
                        'description' => esc_html__( 'How many galleries to display.', 'lsvr-galleries' ),
                        'choices' => array( 0 => esc_html__( 'All', 'lsvr-galleries' ) ) + range( 1, 20, 1 ),
                        'default' => 4,
                    ),

                    // Display date
                    'show_date' => array(
                        'type' => 'checkbox',
                        'label' => esc_html__( 'Display Date', 'lsvr-galleries' ),
                        'default' => true,
                    ),

                    // Display image count
                    'show_image_count' => array(
                        'type' => 'checkbox',
                        'label' => esc_html__( 'Display Image Count', 'lsvr-galleries' ),
                        'default' => true,
                    ),

                    // More label
                    'more_label' => array(
                        'type' => 'text',
                        'label' => esc_html__( 'More Link Label', 'lsvr-galleries' ),
                        'description' => esc_html__( 'Link to galleries archive. Leave blank to hide.', 'lsvr-galleries' ),
                    ),

                    // ID
                    'id' => array(
                        'type' => 'text',
                        'label' => esc_html__( 'Unique ID', 'lsvr-galleries' ),
                        'description' => esc_html__( 'You can use this ID to style this specific element with custom CSS, for example.', 'lsvr-galleries' ),
                    ),

                )
            );
        }

    }
}
?>