<?php
/**
 * LSVR TownPress Widgets Shortcode
 */
if ( ! class_exists( 'Lsvr_Shortcode_Townpress_Sidebar' ) ) {
    class Lsvr_Shortcode_Townpress_Sidebar {

        public static function shortcode( $atts = array(), $content = null, $tag ) {

            // Merge default atts and received atts
            $args = shortcode_atts(
                array(
                    'sidebar_id' => 'lsvr-townpress-default-sidebar-left',
                    'columns_count' => 2,
                    'id' => '',
                ),
                $atts
            );

            ob_start(); ?>

            <section class="lsvr-townpress-sidebar"
                <?php echo ! empty( $args['id'] ) ? ' id="' . esc_attr( $args['id'] ) . '"' : ''; ?>>
                <div class="lsvr-townpress-sidebar__inner">

                    <?php if ( ! empty( $args['sidebar_id'] ) && is_active_sidebar( $args['sidebar_id'] ) ) : ?>

                        <div class="lsvr-townpress-sidebar__list lsvr-townpress-sidebar__list--<?php echo ! empty( $args['columns_count'] ) ? esc_attr( $args['columns_count'] ) : 2; ?>-cols">
                            <?php dynamic_sidebar( $args['sidebar_id'] ); ?>
                        </div>

                    <?php endif; ?>

                </div>
            </section>

            <?php return ob_get_clean();

        }

        // Shortcode params
        public static function lsvr_shortcode_params() {
            return array(
                'base' => 'lsvr_townpress_sidebar',
                'title' => __( 'TownPress Sidebar', 'lsvr-townpress-toolkit' ),
                'description' => __( 'Sidebar with widgets', 'lsvr-townpress-toolkit' ),
                'category' => esc_html__( 'TownPress', 'lsvr-townpress-toolkit' ),
                'fields' => array(

                    // Sidebar ID
                    'sidebar_id' => array(
                        'type' => 'select',
                        'label' => esc_html__( 'Sidebar', 'lsvr-townpress-toolkit' ),
                        'description' => esc_html__( 'Choose which sidebar will be used to create this section. You can manage custom sidebars under Customizer / Custom Sidebars and populate them with widgets under Appearance / Widgets.', 'lsvr-townpress-toolkit' ),
                        'choices' => lsvr_townpress_toolkit_get_sidebars(),
                    ),

                    // Columns count
                    'columns_count' => array(
                        'type' => 'select',
                        'label' => esc_html__( 'Number of Columns', 'lsvr-townpress-toolkit' ),
                        'description' => esc_html__( 'How many columns should be used to display the widgets.', 'lsvr-townpress-toolkit' ),
                        'choices' => range( 1, 4, 1 ),
                        'default' => 2,
                    ),

                    // ID
                    'id' => array(
                        'type' => 'text',
                        'label' => esc_html__( 'Unique ID', 'lsvr-townpress-toolkit' ),
                        'description' => esc_html__( 'You can use this ID to style this specific element with custom CSS, for example.', 'lsvr-townpress-toolkit' ),
                    ),

                )
            );
        }

    }
}
?>