<?php
/**
 * LSVR TownPress Sitemap Shortcode
 */
if ( ! class_exists( 'Lsvr_Shortcode_Townpress_Sitemap' ) ) {
    class Lsvr_Shortcode_Townpress_Sitemap {

        public static function shortcode( $atts = array(), $content = null, $tag ) {

            // Merge default atts and received atts
            $args = shortcode_atts(
                array(
                    'title' => '',
                    'icon' => '',
                    'menu_id' => '',
                    'columns_count' => 3,
                    'id' => '',
                ),
                $atts
            );

            ob_start(); ?>

            <section class="lsvr-townpress-sitemap"
                <?php echo ! empty( $args['id'] ) ? ' id="' . esc_attr( $args['id'] ) . '"' : ''; ?>>
                <div class="c-content-box lsvr-townpress-sitemap__inner">

                    <?php if ( ! empty( $args['icon'] ) ) : ?>
                        <i class="lsvr-townpress-sitemap__icon <?php echo esc_html( $args['icon'] ); ?>"></i>
                    <?php endif; ?>

                    <?php if ( ! empty( $args['title'] ) ) : ?>

                        <header class="lsvr-townpress-sitemap__header">
                            <h2 class="lsvr-townpress-sitemap__title<?php if ( ! empty( $args['icon'] ) ) { echo ' lsvr-townpress-sitemap__title--has-icon'; } ?>">
                                <?php if ( ! empty( $args['icon'] ) ) : ?>
                                    <i class="lsvr-townpress-sitemap__title-icon <?php echo esc_html( $args['icon'] ); ?>"></i>
                                <?php endif; ?>
                                <?php echo wp_kses( $args['title'], array(
                                    'strong' => array(),
                                )); ?>
                            </h2>
                        </header>

                    <?php endif; ?>

                    <?php if ( ! empty( $args['menu_id'] ) ) : ?>

                        <div class="lsvr-townpress-sitemap__content">
                            <nav class="lsvr-townpress-sitemap__nav lsvr-townpress-sitemap__nav--<?php echo ! empty( $args['columns_count'] ) ? esc_attr( $args['columns_count'] ) : 3; ?>-cols">
                                <?php wp_nav_menu(array(
                                    'menu' => $args['menu_id'],
                                    'container' => '',
                                    'menu_class' => 'lsvr-townpress-sitemap__list',
                                    'fallback_cb' => '',
                                    'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s</ul>',
                                    'walker' => new Lsvr_Townpress_Sitemap_Walker,
                                )); ?>
                            </nav>
                        </div>

                    <?php endif; ?>

                </div>
            </section>

            <?php return ob_get_clean();

        }

        // Shortcode params
        public static function lsvr_shortcode_params() {
            return array(
                'base' => 'lsvr_townpress_sitemap',
                'title' => __( 'TownPress Sitemap', 'lsvr-townpress-toolkit' ),
                'description' => __( 'Custom menu', 'lsvr-townpress-toolkit' ),
                'category' => esc_html__( 'TownPress', 'lsvr-townpress-toolkit' ),
                'fields' => array(

                    // Title
                    'title' => array(
                        'type' => 'text',
                        'label' => esc_html__( 'Title', 'lsvr-townpress-toolkit' ),
                        'description' => esc_html__( 'Title of this section.', 'lsvr-townpress-toolkit' ),
                    ),

                    // Icon
                    'icon' => array(
                        'type' => 'text',
                        'label' => esc_html__( 'Icon', 'lsvr-townpress-toolkit' ),
                        'description' => esc_html__( 'For example "icon-road-sign". Please refer to the documentation to learn more about icons.', 'lsvr-townpress-toolkit' ),
                    ),

                    // Menu ID
                    'menu_id' => array(
                        'type' => 'menu',
                        'label' => esc_html__( 'Menu', 'lsvr-townpress-toolkit' ),
                        'description' => esc_html__( 'Choose which menu will be used to create the sitemap. You can manage menus under Appearance / Menus.', 'lsvr-townpress-toolkit' ),
                    ),

                    // Columns count
                    'columns_count' => array(
                        'type' => 'select',
                        'label' => esc_html__( 'Number of Columns', 'lsvr-townpress-toolkit' ),
                        'description' => esc_html__( 'How many columns should be used to display the sitemap.', 'lsvr-townpress-toolkit' ),
                        'choices' => range( 1, 4, 1 ),
                        'default' => 3,
                    ),

                    // ID
                    'id' => array(
                        'type' => 'text',
                        'label' => esc_html__( 'Unique ID', 'lsvr-townpress-toolkit' ),
                        'description' => esc_html__( 'You can use this ID to style this specific element with custom CSS, for example.', 'lsvr-townpress-toolkit' ),
                    ),

                )
            );
        }

    }
}
?>