<?php
/**
 * LSVR TownPress Weather Widget Shortcode
 */
if ( ! class_exists( 'Lsvr_Shortcode_Townpress_Weather_Widget' ) ) {
    class Lsvr_Shortcode_Townpress_Weather_Widget {

        public static function shortcode( $atts = array(), $content = null, $tag ) {

            // Merge default atts and received atts
            $args = shortcode_atts(
                array(
                    'title' => '',
                    'icon' => '',
                    'address' => '',
                    'latitude' => '',
                    'longitude' => '',
                    'forecast_length' => 3,
                    'units_format' => 'metric',
                    'update_interval' => '1hour',
                    'show_time' => 'true',
                    'background_image' => '',
                    'bottom_text' => '',
                    'id' => '',
                ),
                $atts
            );

            ob_start(); ?>

            <?php the_widget( 'Lsvr_Widget_Townpress_Weather', array(
                'title' => $args['title'],
                'address' => $args['address'],
                'latitude' => $args['latitude'],
                'longitude' => $args['longitude'],
                'forecast_length' => $args['forecast_length'],
                'units_format' => $args['units_format'],
                'update_interval' => $args['update_interval'],
                'show_time' => $args['show_time'],
                'background_image' => $args['background_image'],
                'bottom_text' => $args['bottom_text'],
            ), array(
                'before_widget' => '<div' . ( ! empty( $args['id'] ) ? ' id="' . esc_attr( $args['id'] ) . '"' : '' ) . ' class="widget lsvr-townpress-weather-widget"><div class="widget__inner">',
                'after_widget' => '</div></div>',
                'before_title' => ! empty( $args['icon'] ) ? '<h3 class="widget__title widget__title--has-icon"><i class="widget__title-icon ' . esc_attr( $args['icon'] ) . '"></i>' : '<h3 class="widget__title">',
                'after_title' => '</h3>',
            )); ?>

            <?php return ob_get_clean();

        }

        // Shortcode params
        public static function lsvr_shortcode_params() {
            return array(
                'base' => 'lsvr_townpress_weather_widget',
                'title' => __( 'TownPress Weather Widget', 'lsvr-townpress-toolkit' ),
                'description' => __( 'Weather forecast', 'lsvr-townpress-toolkit' ),
                'category' => esc_html__( 'TownPress', 'lsvr-townpress-toolkit' ),
                'is_widget' => true,
                'fields' => array(

                    // Title
                    'title' => array(
                        'type' => 'text',
                        'label' => esc_html__( 'Title', 'lsvr-townpress-toolkit' ),
                        'description' => esc_html__( 'Title of this section.', 'lsvr-townpress-toolkit' ),
                    ),

                    // Address
                    'address' => array(
                        'type' => 'text',
                        'label' => esc_html__( 'Address', 'lsvr-townpress-toolkit' ),
                        'description' => esc_html__( 'For example: "stowe,us". You can search for your location on OpenWeatherMap.org to see if it\'s in the database. Don\'t forget to insert your OpenWeatherMap.org API key under Appearance / Customize / Misc.', 'lsvr-townpress-toolkit' ),
                    ),

                    // Latitude
                    'latitude' => array(
                        'type' => 'text',
                        'label' => esc_html__( 'Latitude', 'lsvr-townpress-toolkit' ),
                        'description' => esc_html__( 'Use if you are unable to get your local weather using just the address.', 'lsvr-townpress-toolkit' ),
                    ),

                    // Longitude
                    'longitude' => array(
                        'type' => 'text',
                        'label' => esc_html__( 'Longitude', 'lsvr-townpress-toolkit' ),
                        'description' => esc_html__( 'Use if you are unable to get your local weather using just the address.', 'lsvr-townpress-toolkit' ),
                    ),

                    // Forecast length
                    'forecast_length' => array(
                        'type' => 'select',
                        'label' => esc_html__( 'Forecast Length', 'lsvr-townpress-toolkit' ),
                        'description' => esc_html__( 'How many days of forecast will be displayed.', 'lsvr-townpress-toolkit' ),
                        'choices' => array(
                            '0' => esc_html__( 'No forecast', 'lsvr-townpress-toolkit' ),
                            '1' => esc_html__( '1 day', 'lsvr-townpress-toolkit' ),
                            '2' => esc_html__( '2 days', 'lsvr-townpress-toolkit' ),
                            '3' => esc_html__( '3 days', 'lsvr-townpress-toolkit' ),
                        ),
                        'default' => '3',
                    ),

                    // Update interval
                    'units_format' => array(
                        'type' => 'select',
                        'label' => esc_html__( 'Units Format', 'lsvr-townpress-toolkit' ),
                        'choices' => array(
                            'metric' => esc_html__( 'Metric', 'lsvr-townpress-toolkit' ),
                            'imperial' => esc_html__( 'Imperial', 'lsvr-townpress-toolkit' ),
                        ),
                        'default' => 'metric',
                    ),

                    // Update interval
                    'update_interval' => array(
                        'type' => 'select',
                        'label' => esc_html__( 'Update Interval', 'lsvr-townpress-toolkit' ),
                        'description' => esc_html__( 'How often should be weather data pulled from openweathermap.org.', 'lsvr-townpress-toolkit' ),
                        'choices' => array(
                            '10min' => esc_html__( 'Every 10 minutes', 'lsvr-townpress-toolkit' ),
                            '30min' => esc_html__( 'Every 30 minutes', 'lsvr-townpress-toolkit' ),
                            '1hour' => esc_html__( 'Every hour', 'lsvr-townpress-toolkit' ),
                            '3hours' => esc_html__( 'Every 3 hours', 'lsvr-townpress-toolkit' ),
                            '12hours' => esc_html__( 'Every 12 hours', 'lsvr-townpress-toolkit' ),
                            '24hours' => esc_html__( 'Every 24 hours', 'lsvr-townpress-toolkit' ),
                            'disable' => esc_html__( 'On each page load (not recommended)', 'lsvr-townpress-toolkit' ),
                        ),
                        'default' => '1hour',
                    ),

                    // Display local time
                    'show_time' => array(
                        'type' => 'checkbox',
                        'label' => esc_html__( 'Display Local Time', 'lsvr-townpress-toolkit' ),
                        'description' => esc_html__( 'You can change your Timezone and Time Format under Settings / General.', 'lsvr-townpress-toolkit' ),
                        'default' => true,
                    ),

                    // background image
                    'background_image' => array(
                        'type' => 'image',
                        'label' => esc_html__( 'Background Image', 'lsvr-townpress-toolkit' ),
                        'description' => esc_html__( 'Optimal resolution is about 600x600px.', 'lsvr-townpress-toolkit' ),
                    ),

                    // Bottom text
                    'bottom_text' => array(
                        'type' => 'text',
                        'label' => esc_html__( 'Bottom Text', 'lsvr-townpress-toolkit' ),
                        'description' => esc_html__( 'Custom text which will be displayed at the bottom of the widget content.', 'lsvr-townpress-toolkit' ),
                    ),

                    // ID
                    'id' => array(
                        'type' => 'text',
                        'label' => esc_html__( 'Unique ID', 'lsvr-townpress-toolkit' ),
                        'description' => esc_html__( 'Custom text which will be displayed at the bottom of the widget content.', 'lsvr-townpress-toolkit' ),
                    ),

                )
            );
        }

    }
}
?>