<?php
/**
 * LSVR Posts widget
 *
 * Display list of posts
 */
if ( ! class_exists( 'Lsvr_Widget_Townpress_Post_List' ) && class_exists( 'Lsvr_Widget' ) ) {
class Lsvr_Widget_Townpress_Post_List extends Lsvr_Widget {

    public function __construct() {

    	// Init widget
		parent::__construct(array(
			'id' => 'lsvr_townpress_post_list',
			'classname' => 'lsvr-townpress-post-list-widget',
			'title' => esc_html__( 'TownPress Posts', 'lsvr-townpress-toolkit' ),
			'description' => esc_html__( 'List of Posts', 'lsvr-townpress-toolkit' ),
			'fields' => array(
				'title' => array(
					'label' => esc_html__( 'Title:', 'lsvr-townpress-toolkit' ),
					'type' => 'text',
					'default' => esc_html__( 'News', 'lsvr-townpress-toolkit' ),
				),
				'category' => array(
					'label' => esc_html__( 'Category:', 'lsvr-townpress-toolkit' ),
					'description' => esc_html__( 'Display posts only from certain category.', 'lsvr-townpress-toolkit' ),
					'type' => 'taxonomy',
					'taxonomy' => 'category',
					'default_label' => esc_html__( 'None', 'lsvr-townpress-toolkit' ),
				),
				'limit' => array(
					'label' => esc_html__( 'Limit:', 'lsvr-townpress-toolkit' ),
					'description' => esc_html__( 'Number of posts to display.', 'lsvr-townpress-toolkit' ),
					'type' => 'select',
					'choices' => array( 0 => esc_html__( 'All', 'lsvr-townpress-toolkit' ) ) + range( 1, 20, 1 ),
					'default' => 4,
				),
				'show_date' => array(
					'label' => esc_html__( 'Display Date', 'lsvr-townpress-toolkit' ),
					'type' => 'checkbox',
					'default' => 'true',
				),
				'show_category' => array(
					'label' => esc_html__( 'Display Category', 'lsvr-townpress-toolkit' ),
					'type' => 'checkbox',
					'default' => 'true',
				),
				'more_label' => array(
					'label' => esc_html__( 'More Button Label:', 'lsvr-townpress-toolkit' ),
					'description' => esc_html__( 'Link to post archive. Leave blank to hide.', 'lsvr-townpress-toolkit' ),
					'type' => 'text',
					'default' => esc_html__( 'More Posts', 'lsvr-townpress-toolkit' ),
				),
			),
		));

    }

    function widget( $args, $instance ) {

		// Set posts limit
		$limit = array_key_exists( 'limit', $instance ) && (int) $instance[ 'limit' ] > 0 ? $instance[ 'limit' ] : 1000;

    	// Get posts
    	$query_args = array(
    		'post_type' => 'post',
    		'posts_per_page' => $limit,
		);
		if ( ! empty( $instance['category'] ) && 'none' !== $instance['category'] ) {
			$query_args['tax_query'] = array(
				array(
					'taxonomy' => 'category',
					'field' => 'term_id',
					'terms' => $instance['category'],
				),
			);
		}
    	$posts = get_posts( $query_args );
        ?>

        <?php // Before widget content
        parent::before_widget_content( $args, $instance ); ?>

        <div class="widget__content">

        	<?php if ( ! empty( $posts ) ) : ?>

        		<ul class="lsvr-townpress-post-list-widget__list">
	        		<?php foreach ( $posts as $post ) : ?>

	        			<li class="lsvr-townpress-post-list-widget__item">

		        			<h4 class="lsvr-townpress-post-list-widget__item-title">
		        				<a href="<?php echo esc_url( get_permalink( $post->ID ) ); ?>" class="lsvr-townpress-post-list-widget__item-title-link">
		        					<?php echo get_the_title( $post->ID ); ?>
		        				</a>
		        			</h4>

		        			<?php if ( ( ! empty( $instance['show_date'] ) && 'true' === $instance['show_date'] ) ||
								( ! empty( $instance['show_category'] ) && 'true' === $instance['show_category'] && ! empty( get_the_terms( $post->ID, 'category' ) ) ) ) : ?>

								<ul class="lsvr-townpress-post-list-widget__item-meta">

									<?php // Date
									if ( ! empty( $instance['show_date'] ) && 'true' === $instance['show_date'] ) : ?>
										<li class="lsvr-townpress-post-list-widget__item-meta-item lsvr-townpress-post-list-widget__item-meta-item--date">
											<time datetime="<?php echo esc_attr( date( 'c', strtotime( $post->post_date ) ) ); ?>">
												<?php echo esc_html( date_i18n( get_option( 'date_format' ), strtotime( $post->post_date ) ) ); ?>
											</time>
										</li>
									<?php endif; ?>

									<?php // Category
									$terms = get_the_terms( $post->ID, 'category' );
									$category_html = '';
									if ( ! empty( $terms ) ) {
										foreach ( $terms as $term ) {
											$category_html .= '<a href="' . esc_url( get_term_link( $term->term_id, 'category' ) ) . '" class="lsvr-townpress-post-list-widget__item-category-link">' . $term->name . '</a>';
											$category_html .= $term !== end( $terms ) ? ', ' : '';
										}
									}
									if ( ! empty( $instance['show_category'] ) && 'true' === $instance['show_category'] && ! empty( $category_html ) ) : ?>
										<li class="lsvr-townpress-post-list-widget__item-meta-item lsvr-townpress-post-list-widget__item-meta-item--category">
											<?php echo sprintf( esc_html__( 'in %s', 'lsvr-townpress-toolkit' ), $category_html ); ?>
										</li>
									<?php endif; ?>

								</ul>

							<?php endif; ?>

	        			</li>

	        		<?php endforeach; ?>
        		</ul>

				<?php if ( ! empty( $instance[ 'more_label' ] ) ) : ?>
				<p class="widget__more">
					<?php if ( ! empty( $instance['category'] ) && ! empty( term_exists( (int) $instance['category'], 'category' ) ) ) : ?>
						<a href="<?php echo esc_url( get_term_link( (int) $instance['category'], 'category' ) ); ?>" class="widget__more-link"><?php echo esc_html( $instance[ 'more_label' ] ); ?></a>
					<?php else : ?>
						<a href="<?php echo esc_url( get_post_type_archive_link( 'post' ) ); ?>" class="widget__more-link"><?php echo esc_html( $instance[ 'more_label' ] ); ?></a>
					<?php endif; ?>
				</p>
				<?php endif; ?>

        	<?php else : ?>
        		<p class="widget__no-results"><?php esc_html_e( 'There are no posts', 'lsvr-townpress-toolkit' ); ?></p>
        	<?php endif; ?>

        </div>

        <?php // After widget content
        parent::after_widget_content( $args, $instance ); ?>

        <?php

    }

}}

?>